@@ -2,7 +2,7 @@ package DBIx::TransactionManager;
 use strict;
 use warnings;
 use Carp ();
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 sub new {
     my ($class, $dbh) = @_;
@@ -63,6 +63,8 @@ sub txn_end {
     $_[0]->{rollbacked_in_nested_transaction} = 0;
 }
 
+sub in_transaction { $_[0]->{active_transaction} ? 1 : 0 }
+
 package DBIx::TransactionManager::ScopeGuard;
 use Try::Tiny;
 
@@ -195,6 +197,10 @@ Commit the transaction.
 
 Rollback the transaction.
 
+=head2 $txn->in_transaction
+
+are you in transaction?
+
 =head1 AUTHOR
 
 Atsushi Kobayashi E<lt>nekokak _at_ gmail _dot_ comE<gt>
